@@ -1,34 +1,50 @@
 /*
   This file is part of the clazy static checker.
 
-  Copyright (C) 2016 Sergio Martins <smartins@kde.org>
-  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Copyright (C) 2016 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "AccessSpecifierManager.h"
-
-#include "StringUtils.h"
-#include "HierarchyUtils.h"
 #include "QtUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "Utils.h"
 
 #include <clang/Basic/SourceManager.h>
-#include <clang/Parse/Parser.h>
 #include <clang/AST/DeclCXX.h>
+#include <clang/AST/DeclBase.h>
+#include <clang/AST/DeclTemplate.h>
+#include <clang/Basic/IdentifierTable.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Frontend/CompilerInstance.h>
+#include <clang/Lex/PPCallbacks.h>
+#include <clang/Lex/Preprocessor.h>
+#include <clang/Lex/Token.h>
+#include <llvm/Support/Casting.h>
+
+#include <algorithm>
+#include <memory>
+#include <utility>
+
+namespace clang {
+class MacroArgs;
+class MacroDefinition;
+}  // namespace clang
 
 using namespace clang;
 using namespace std;
@@ -61,7 +77,8 @@ static void sorted_insert(ClazySpecifierList &v, const ClazyAccessSpecifier &ite
     v.insert(std::upper_bound(v.begin(), v.end(), item, pred), item);
 }
 
-class AccessSpecifierPreprocessorCallbacks : public clang::PPCallbacks
+class AccessSpecifierPreprocessorCallbacks
+    : public clang::PPCallbacks
 {
     AccessSpecifierPreprocessorCallbacks(const AccessSpecifierPreprocessorCallbacks &) = delete;
 public:
@@ -137,7 +154,7 @@ const CXXRecordDecl *AccessSpecifierManager::classDefinitionForLoc(SourceLocatio
 {
     for (const auto &it : m_specifiersMap) {
         const CXXRecordDecl *record = it.first;
-        if (getLocStart(record) < loc && loc < getLocEnd(record))
+        if (clazy::getLocStart(record) < loc && loc < clazy::getLocEnd(record))
             return record;
     }
     return nullptr;
@@ -171,13 +188,13 @@ void AccessSpecifierManager::VisitDeclaration(Decl *decl)
         if (!accessSpec || accessSpec->getDeclContext() != record)
             continue;
         ClazySpecifierList &specifiers = entryForClassDefinition(record);
-        sorted_insert(specifiers, {getLocStart(accessSpec), accessSpec->getAccess(), QtAccessSpecifier_None }, sm);
+        sorted_insert(specifiers, {clazy::getLocStart(accessSpec), accessSpec->getAccess(), QtAccessSpecifier_None }, sm);
     }
 }
 
 QtAccessSpecifierType AccessSpecifierManager::qtAccessSpecifierType(const CXXMethodDecl *method) const
 {
-    if (!method || getLocStart(method).isMacroID())
+    if (!method || clazy::getLocStart(method).isMacroID())
         return QtAccessSpecifier_Unknown;
 
     // We want the declaration that's inside class {}, not the ones that are also a method definition
@@ -188,7 +205,7 @@ QtAccessSpecifierType AccessSpecifierManager::qtAccessSpecifierType(const CXXMet
     if (!record || isa<clang::ClassTemplateSpecializationDecl>(record))
         return QtAccessSpecifier_None;
 
-    const SourceLocation methodLoc = getLocStart(method);
+    const SourceLocation methodLoc = clazy::getLocStart(method);
 
     // Process Q_SIGNAL:
     for (auto signalLoc : m_preprocessorCallbacks->m_individualSignals) {
