@@ -1,46 +1,54 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "Utils.h"
 #include "Clazy.h"
-#include "StringUtils.h"
 #include "clazy_stl.h"
 #include "checkbase.h"
 #include "AccessSpecifierManager.h"
+#include "SourceCompatibilityHelpers.h"
 
-#include "clang/Frontend/FrontendPluginRegistry.h"
-#include "clang/AST/AST.h"
-
-#include "clang/Frontend/CompilerInstance.h"
-#include "llvm/Support/raw_ostream.h"
-#include "clang/AST/ParentMap.h"
-#include <llvm/Config/llvm-config.h>
+#include <clang/Frontend/FrontendPluginRegistry.h>
+#include <clang/Frontend/CompilerInstance.h>
+#include <clang/AST/ParentMap.h>
+#include <clang/AST/ASTConsumer.h>
+#include <clang/AST/ASTContext.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclBase.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/StmtCXX.h>
+#include <clang/Basic/Diagnostic.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceLocation.h>
+#include <clang/Basic/SourceManager.h>
+#include <clang/Frontend/FrontendAction.h>
+#include <llvm/Support/raw_ostream.h>
+#include <llvm/Support/Casting.h>
 
+#include <stdlib.h>
 #include <mutex>
-#include <stdio.h>
-#include <sstream>
-#include <iostream>
 
 using namespace clang;
 using namespace std;
@@ -98,7 +106,7 @@ bool ClazyASTConsumer::VisitDecl(Decl *decl)
     if (AccessSpecifierManager *a = m_context->accessSpecifierManager) // Needs to visit system headers too (qobject.h for example)
         a->VisitDeclaration(decl);
 
-    const SourceLocation locStart = getLocStart(decl);
+    const SourceLocation locStart = clazy::getLocStart(decl);
     if (locStart.isInvalid() || m_context->sm.isInSystemHeader(locStart))
         return true;
 
@@ -118,7 +126,7 @@ bool ClazyASTConsumer::VisitDecl(Decl *decl)
 
 bool ClazyASTConsumer::VisitStmt(Stmt *stm)
 {
-    const SourceLocation locStart = getLocStart(stm);
+    const SourceLocation locStart = clazy::getLocStart(stm);
     if (locStart.isInvalid() || m_context->sm.isInSystemHeader(locStart))
         return true;
 
@@ -215,8 +223,11 @@ bool ClazyASTAction::ParseArgs(const CompilerInstance &ci, const std::vector<std
 
     std::vector<std::string> args = args_;
 
+    const string headerFilter = getEnvVariable("CLAZY_HEADER_FILTER");
+    const string ignoreDirs = getEnvVariable("CLAZY_IGNORE_DIRS");
+
     if (parseArgument("help", args)) {
-        m_context = new ClazyContext(ci, getEnvVariable("CLAZY_HEADER_FILTER"), getEnvVariable("CLAZY_IGNORE_DIRS"), ClazyContext::ClazyOption_None);
+        m_context = new ClazyContext(ci, headerFilter, ignoreDirs, ClazyContext::ClazyOption_None);
         PrintHelp(llvm::errs());
         return true;
     }
@@ -249,7 +260,7 @@ bool ClazyASTAction::ParseArgs(const CompilerInstance &ci, const std::vector<std
     if (parseArgument("ignore-included-files", args))
         m_options |= ClazyContext::ClazyOption_IgnoreIncludedFiles;
 
-    m_context = new ClazyContext(ci, /*headerFilter=*/ "", /*ignoreDirs=*/ "", m_options);
+    m_context = new ClazyContext(ci, headerFilter, ignoreDirs, m_options);
 
     // This argument is for debugging purposes
     const bool dbgPrintRequestedChecks = parseArgument("print-requested-checks", args);
@@ -347,7 +358,7 @@ void ClazyASTAction::PrintHelp(llvm::raw_ostream &ros) const
     ros << "    export CLAZY_CHECKS=\"level0,reserve-candidates,qstring-allocations\"\n";
     ros << "    export CLAZY_CHECKS=\"reserve-candidates\"\n\n";
     ros << "or pass as compiler arguments, for example:\n";
-    ros << "    -Xclang -plugin-arg-clang-lazy -Xclang reserve-candidates,qstring-allocations\n";
+    ros << "    -Xclang -plugin-arg-clazy -Xclang reserve-candidates,qstring-allocations\n";
     ros << "\n";
     ros << "To enable FixIts for a check, also set the env variable CLAZY_FIXIT, for example:\n";
     ros << "    export CLAZY_FIXIT=\"fix-qlatin1string-allocations\"\n\n";
@@ -384,10 +395,10 @@ unique_ptr<ASTConsumer> ClazyStandaloneASTAction::CreateASTConsumer(CompilerInst
         astConsumer->addCheck(check);
     }
 
-   return unique_ptr<ASTConsumer>(astConsumer);
+    return unique_ptr<ASTConsumer>(astConsumer);
 }
 
 volatile int ClazyPluginAnchorSource = 0;
 
 static FrontendPluginRegistry::Add<ClazyASTAction>
-X("clang-lazy", "clang lazy plugin");
+X("clazy", "clang lazy plugin");
