@@ -1,25 +1,25 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef CLAZY_AST_ACTION_H
@@ -27,23 +27,34 @@
 
 #include "checkmanager.h"
 #include "ClazyContext.h"
+#include "checkbase.h"
 
 #include <clang/AST/ASTConsumer.h>
 #include <clang/Frontend/FrontendAction.h>
-#include "clang/AST/RecursiveASTVisitor.h"
+#include <clang/AST/RecursiveASTVisitor.h>
+#include <llvm/ADT/StringRef.h>
 
 #include <memory>
 #include <vector>
 #include <string>
+#include <utility>
+
+namespace llvm {
+class raw_ostream;
+}  // namespace llvm
 
 namespace clang {
-    class CompilerInstance;
+class CompilerInstance;
+class ASTContext;
+class Decl;
+class Stmt;
 }
 
 /**
  * This is the FrontendAction that is run with clazy is used as a plugin.
  */
-class ClazyASTAction : public clang::PluginASTAction
+class ClazyASTAction
+    : public clang::PluginASTAction
 {
 public:
     ClazyASTAction();
@@ -68,7 +79,8 @@ private:
  * This is the FrontendAction that is run with clazy is used standalone instead of as a plugin.
  * i.e: when you run clazy-standalone, this is the invoked FrontendAction
  */
-class ClazyStandaloneASTAction : public clang::ASTFrontendAction
+class ClazyStandaloneASTAction
+    : public clang::ASTFrontendAction
 {
 public:
     explicit ClazyStandaloneASTAction(const std::string &checkList,
@@ -87,8 +99,9 @@ private:
 /**
  * Clazy's AST Consumer.
  */
-class ClazyASTConsumer : public clang::ASTConsumer,
-                         public clang::RecursiveASTVisitor<ClazyASTConsumer>
+class ClazyASTConsumer
+    : public clang::ASTConsumer
+    , public clang::RecursiveASTVisitor<ClazyASTConsumer>
 {
 public:
     explicit ClazyASTConsumer(ClazyContext *context);
