@@ -1,22 +1,22 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "AccessSpecifierManager.h"
@@ -24,19 +24,27 @@
 #include "ClazyContext.h"
 
 #include <clang/AST/ParentMap.h>
-#include <clang/Basic/SourceManager.h>
-#include "clang/Rewrite/Frontend/FixItRewriter.h"
+#include <clang/Rewrite/Frontend/FixItRewriter.h>
+#include <clang/Frontend/CompilerInstance.h>
+#include <clang/Lex/PreprocessorOptions.h>
+#include <llvm/Support/Regex.h>
+
+#include <stdlib.h>
 
 using namespace std;
 using namespace clang;
 
-class ClazyFixItOptions : public FixItOptions
+class ClazyFixItOptions
+    : public FixItOptions
 {
 public:
     ClazyFixItOptions(const ClazyFixItOptions &other) = delete;
     ClazyFixItOptions(bool inplace)
     {
-        InPlace = inplace;
+        if (const char *suffix = getenv("CLAZY_FIXIT_SUFFIX"))
+            m_suffix = suffix;
+
+        InPlace = inplace && m_suffix.empty();
         FixWhatYouCan = true;
         FixOnlyWarnings = true;
         Silent = false;
@@ -45,8 +53,11 @@ public:
     std::string RewriteFilename(const std::string &filename, int &fd) override
     {
         fd = -1;
-        return InPlace ? filename : filename + "_fixed.cpp";
+        return InPlace ? filename
+                       : filename + m_suffix;
     }
+
+    std::string m_suffix;
 };
 
 ClazyContext::ClazyContext(const clang::CompilerInstance &compiler,
@@ -116,7 +127,7 @@ bool ClazyContext::isQt() const
                 return true;
         }
         return false;
-    }();
+    } ();
 
     return s_isQt;
 }
