@@ -1,48 +1,53 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef CLAZY_CONTEXT_H
 #define CLAZY_CONTEXT_H
 
 #include "SuppressionManager.h"
-
 #include "clazy_stl.h"
 
 #include <clang/Frontend/CompilerInstance.h>
 #include <clang/Lex/PreprocessorOptions.h>
 #include <clang/Basic/FileManager.h>
+#include <clang/Basic/SourceLocation.h>
+#include <clang/Basic/SourceManager.h>
 #include <llvm/Support/Regex.h>
+#include <llvm/ADT/StringRef.h>
 
 #include <string>
 #include <vector>
 #include <memory>
+#include <utility>
 
 // ClazyContext is just a struct to share data and code between all checks
 
 namespace clang {
-    class CompilerInstance;
-    class ASTContext;
-    class ParentMap;
-    class SourceManager;
-    class FixItRewriter;
+class CompilerInstance;
+class ASTContext;
+class ParentMap;
+class SourceManager;
+class FixItRewriter;
+class CXXMethodDecl;
+class Decl;
 }
 
 class AccessSpecifierManager;
@@ -124,7 +129,7 @@ public:
             }
         }
 
-        StringRef fileName((*file)->getName());
+        llvm::StringRef fileName((*file)->getName());
         return regex->match(fileName);
     }
 
