@@ -1,34 +1,40 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 // clazy:excludeall=non-pod-global-static
 
 #include "Clazy.h"
+#include "ClazyContext.h"
 
-#include <clang/Frontend/FrontendActions.h>
 #include <clang/Tooling/CommonOptionsParser.h>
 #include <clang/Tooling/Tooling.h>
 #include <llvm/Support/CommandLine.h>
+#include <llvm/ADT/ArrayRef.h>
+#include <llvm/ADT/StringRef.h>
 
-#include <memory>
+#include <string>
+
+namespace clang {
+class FrontendAction;
+}  // namespace clang
 
 using namespace clang;
 using namespace clang::tooling;
@@ -51,27 +57,28 @@ static cl::opt<bool> s_onlyQt("only-qt", cl::desc("Won't emit warnings for non-Q
                               cl::init(false), cl::cat(s_clazyCategory));
 
 static cl::opt<bool> s_qtDeveloper("qt-developer", cl::desc("For running clazy on Qt itself, optional, but honours specific guidelines"),
-                              cl::init(false), cl::cat(s_clazyCategory));
+                                   cl::init(false), cl::cat(s_clazyCategory));
 
 static cl::opt<bool> s_visitImplicitCode("visit-implicit-code", cl::desc("For visiting implicit code like compiler generated constructors. None of the built-in checks benefit from this, but can be useful for custom checks"),
-                              cl::init(false), cl::cat(s_clazyCategory));
+                                         cl::init(false), cl::cat(s_clazyCategory));
 
 static cl::opt<bool> s_ignoreIncludedFiles("ignore-included-files", cl::desc("Only emit warnings for the current file being compiled and ignore any includes. Useful for performance reasons."),
-                              cl::init(false), cl::cat(s_clazyCategory));
+                                           cl::init(false), cl::cat(s_clazyCategory));
 
 static cl::opt<std::string> s_headerFilter("header-filter", cl::desc(R"(Regular expression matching the names of the
 headers to output diagnostics from. Diagnostics
 from the main file of each translation unit are
 always displayed.)"),
-                              cl::init(""), cl::cat(s_clazyCategory));
+                                           cl::init(""), cl::cat(s_clazyCategory));
 
 static cl::opt<std::string> s_ignoreDirs("ignore-dirs", cl::desc(R"(Regular expression matching the names of the
 directories for which diagnostics should never be emitted. Useful for ignoring 3rdparty code.)"),
-                              cl::init(""), cl::cat(s_clazyCategory));
+                                         cl::init(""), cl::cat(s_clazyCategory));
 
 static cl::extrahelp s_commonHelp(CommonOptionsParser::HelpMessage);
 
-class ClazyToolActionFactory : public clang::tooling::FrontendActionFactory
+class ClazyToolActionFactory
+    : public clang::tooling::FrontendActionFactory
 {
 public:
     ClazyToolActionFactory()
