@@ -1,22 +1,22 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef CLAZY_PREPROCESSOR_VISITOR_H
@@ -29,22 +29,27 @@
 
 #include "checkbase.h"
 
-#include <string>
 #include <clang/Lex/PPCallbacks.h>
+#include <llvm/ADT/StringRef.h>
+
+#include <string>
 #include <unordered_map>
+#include <vector>
 
 namespace clang {
-    class CompilerInstance;
-    class SourceManager;
-    class SourceRange;
-    class Token;
-    class MacroDefinition;
-    class MacroArgs;
+class CompilerInstance;
+class SourceManager;
+class SourceRange;
+class Token;
+class MacroDefinition;
+class MacroArgs;
+class SourceLocation;
 }
 
 using uint = unsigned;
 
-class PreProcessorVisitor : public clang::PPCallbacks
+class PreProcessorVisitor
+    : public clang::PPCallbacks
 {
     PreProcessorVisitor(const PreProcessorVisitor &) = delete;
 public:
