@@ -1,22 +1,22 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015-2016 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015-2016 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "clazy_stl.h"
@@ -24,12 +24,12 @@
 #include "Utils.h"
 #include "TypeUtils.h"
 #include "StmtBodyRange.h"
-#include "MacroUtils.h"
-#include "HierarchyUtils.h"
 #include "StringUtils.h"
-#include "ContextUtils.h"
 
-#include <clang/AST/AST.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/ADT/ArrayRef.h>
+#include <llvm/Support/raw_ostream.h>
 
 using namespace std;
 using namespace clang;
@@ -59,9 +59,9 @@ const vector<StringRef> & clazy::qtCOWContainers()
 }
 
 
-std::unordered_map<string, std::vector<StringRef> > clazy::detachingMethods()
+std::unordered_map<string, std::vector<StringRef>> clazy::detachingMethods()
 {
-    static std::unordered_map<string, std::vector<StringRef> > map;
+    static std::unordered_map<string, std::vector<StringRef>> map;
     if (map.empty()) {
         map = detachingMethodsWithConstCounterParts();
         map["QVector"].push_back("fill");
@@ -70,9 +70,9 @@ std::unordered_map<string, std::vector<StringRef> > clazy::detachingMethods()
     return map;
 }
 
-std::unordered_map<string, std::vector<StringRef> > clazy::detachingMethodsWithConstCounterParts()
+std::unordered_map<string, std::vector<StringRef>> clazy::detachingMethodsWithConstCounterParts()
 {
-    static std::unordered_map<string, std::vector<StringRef> > map;
+    static std::unordered_map<string, std::vector<StringRef>> map;
     if (map.empty()) {
         map["QList"] = {"first", "last", "begin", "end", "front", "back", "operator[]"};
         map["QVector"] = {"first", "last", "begin", "end", "front", "back", "data", "operator[]" };
