@@ -1,39 +1,53 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "checkbase.h"
-
 #include "ClazyContext.h"
-#include "StringUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "SuppressionManager.h"
+#include "Utils.h"
+#include "clazy_stl.h"
 
-#include <clang/AST/Decl.h>
-#include <clang/AST/DeclCXX.h>
-#include <clang/AST/ASTContext.h>
-#include <clang/Rewrite/Frontend/FixItRewriter.h>
+#include <clang/AST/DeclBase.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/Diagnostic.h>
+#include <clang/Basic/DiagnosticIDs.h>
+#include <clang/Basic/SourceManager.h>
+#include <clang/Frontend/CompilerInstance.h>
+#include <clang/Lex/MacroInfo.h>
+#include <clang/Lex/Preprocessor.h>
+#include <llvm/ADT/IntrusiveRefCntPtr.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/raw_ostream.h>
 
 #include <vector>
-#include <chrono>
+#include <memory>
+
+namespace clang {
+class MacroArgs;
+class Token;
+}  // namespace clang
 
 using namespace clang;
 using namespace clang::ast_matchers;
@@ -60,6 +74,31 @@ void ClazyPreprocessorCallbacks::Ifdef(SourceLocation loc, const Token &macroNam
     check->VisitIfdef(loc, macroNameTok);
 }
 
+void ClazyPreprocessorCallbacks::Ifndef(SourceLocation loc, const Token &macroNameTok, const MacroDefinition &)
+{
+    check->VisitIfndef(loc, macroNameTok);
+}
+
+void ClazyPreprocessorCallbacks::If(SourceLocation loc, SourceRange conditionRange, PPCallbacks::ConditionValueKind conditionValue)
+{
+    check->VisitIf(loc, conditionRange, conditionValue);
+}
+
+void ClazyPreprocessorCallbacks::Elif(SourceLocation loc, SourceRange conditionRange, PPCallbacks::ConditionValueKind conditionValue, SourceLocation ifLoc)
+{
+    check->VisitElif(loc, conditionRange, conditionValue, ifLoc);
+}
+
+void ClazyPreprocessorCallbacks::Else(SourceLocation loc, SourceLocation ifLoc)
+{
+    check->VisitElse(loc, ifLoc);
+}
+
+void ClazyPreprocessorCallbacks::Endif(SourceLocation loc, SourceLocation ifLoc)
+{
+    check->VisitEndif(loc, ifLoc);
+}
+
 void ClazyPreprocessorCallbacks::MacroDefined(const Token &macroNameTok, const MacroDirective *)
 {
     check->VisitMacroDefined(macroNameTok);
@@ -110,6 +149,31 @@ void CheckBase::VisitIfdef(clang::SourceLocation, const clang::Token &)
     // Overriden in derived classes
 }
 
+void CheckBase::VisitIfndef(SourceLocation, const Token &)
+{
+    // Overriden in derived classes
+}
+
+void CheckBase::VisitIf(SourceLocation, SourceRange,  clang::PPCallbacks::ConditionValueKind)
+{
+    // Overriden in derived classes
+}
+
+void CheckBase::VisitElif(SourceLocation, SourceRange,  clang::PPCallbacks::ConditionValueKind, SourceLocation)
+{
+    // Overriden in derived classes
+}
+
+void CheckBase::VisitElse(SourceLocation, SourceLocation)
+{
+    // Overriden in derived classes
+}
+
+void CheckBase::VisitEndif(SourceLocation, SourceLocation)
+{
+    // Overriden in derived classes
+}
+
 void CheckBase::enablePreProcessorCallbacks()
 {
     Preprocessor &pi = m_context->ci.getPreprocessor();
@@ -133,12 +197,12 @@ bool CheckBase::shouldIgnoreFile(SourceLocation loc) const
 
 void CheckBase::emitWarning(const clang::Decl *d, const std::string &error, bool printWarningTag)
 {
-    emitWarning(getLocStart(d), error, printWarningTag);
+    emitWarning(clazy::getLocStart(d), error, printWarningTag);
 }
 
 void CheckBase::emitWarning(const clang::Stmt *s, const std::string &error, bool printWarningTag)
 {
-    emitWarning(getLocStart(s), error, printWarningTag);
+    emitWarning(clazy::getLocStart(s), error, printWarningTag);
 }
 
 void CheckBase::emitWarning(clang::SourceLocation loc, const std::string &error, bool printWarningTag)
