@@ -1,35 +1,40 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "checkmanager.h"
 #include "clazy_stl.h"
 #include "ClazyContext.h"
-#include "Utils.h"
-#include "StringUtils.h"
 #include "Checks.h"
 
+#include <llvm/Support/raw_ostream.h>
+
 #include <stdlib.h>
+#include <assert.h>
+#include <string.h>
+#include <algorithm>
+#include <iterator>
+#include <memory>
 
 using namespace clang;
 using namespace std;
@@ -123,21 +128,16 @@ RegisteredCheck::List CheckManager::availableChecks(CheckLevel maxLevel) const
     return checks;
 }
 
-RegisteredCheck::List CheckManager::requestedChecksThroughEnv(const ClazyContext *context) const
-{
-    vector<string> dummy;
-    return requestedChecksThroughEnv(context, dummy);
-}
-
 RegisteredCheck::List CheckManager::requestedChecksThroughEnv(const ClazyContext *context, vector<string> &userDisabledChecks) const
 {
     static RegisteredCheck::List requestedChecksThroughEnv;
+    static vector<string> disabledChecksThroughEnv;
     if (requestedChecksThroughEnv.empty()) {
         const char *checksEnv = getenv("CLAZY_CHECKS");
         if (checksEnv) {
             const string checksEnvStr = clazy::unquoteString(checksEnv);
             requestedChecksThroughEnv = checksEnvStr == "all_checks" ? availableChecks(CheckLevel2)
-                                                                     : checksForCommaSeparatedString(checksEnvStr, /*by-ref=*/ userDisabledChecks);
+                                                                     : checksForCommaSeparatedString(checksEnvStr, /*by-ref=*/ disabledChecksThroughEnv);
         }
 
         const string checkName = checkNameForFixIt(context->requestedFixitName);
@@ -146,6 +146,8 @@ RegisteredCheck::List CheckManager::requestedChecksThroughEnv(const ClazyContext
         }
     }
 
+    std::copy(disabledChecksThroughEnv.begin(), disabledChecksThroughEnv.end(),
+              std::back_inserter(userDisabledChecks));
     return requestedChecksThroughEnv;
 }
 
@@ -202,7 +204,7 @@ RegisteredCheck::List CheckManager::requestedChecks(const ClazyContext *context,
     // #3 Append checks specified from env variable
 
     vector<string> userDisabledChecks;
-    RegisteredCheck::List checksFromEnv = requestedChecksThroughEnv(context, /*by-ref*/userDisabledChecks);
+    RegisteredCheck::List checksFromEnv = requestedChecksThroughEnv(context, /*by-ref*/ userDisabledChecks);
     copy(checksFromEnv.cbegin(), checksFromEnv.cend(), back_inserter(result));
 
     if (result.empty() && requestedLevel == CheckLevelUndefined) {
@@ -219,7 +221,7 @@ RegisteredCheck::List CheckManager::requestedChecks(const ClazyContext *context,
     if (context->options & ClazyContext::ClazyOption_Qt4Compat) {
         // #5 Remove Qt4 incompatible checks
         result.erase(remove_if(result.begin(), result.end(), [](const RegisteredCheck &c){
-           return c.options & RegisteredCheck::Option_Qt4Incompatible;
+            return c.options & RegisteredCheck::Option_Qt4Incompatible;
         }), result.end());
     }
 
