@@ -1,22 +1,22 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "qstring-ref.h"
@@ -25,13 +25,30 @@
 #include "HierarchyUtils.h"
 #include "StringUtils.h"
 #include "FixItUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "clazy_stl.h"
 
-#include <clang/AST/AST.h>
 #include <clang/Lex/Lexer.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/Diagnostic.h>
+#include <clang/Basic/IdentifierTable.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceLocation.h>
+#include <llvm/ADT/SmallVector.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
 
 #include <array>
 #include <vector>
 
+namespace clang {
+class Decl;
+class LangOptions;
+}  // namespace clang
+
 using namespace clang;
 using namespace std;
 
@@ -55,8 +72,8 @@ static bool isInterestingSecondMethod(CXXMethodDecl *method, const clang::LangOp
         return false;
 
     static const std::array<StringRef, 19> list = {{ "compare", "contains", "count", "startsWith", "endsWith", "indexOf",
-                                                     "isEmpty", "isNull", "lastIndexOf", "length", "size", "toDouble", "toFloat",
-                                                     "toInt", "toUInt", "toULong", "toULongLong", "toUShort", "toUcs4" }};
+        "isEmpty", "isNull", "lastIndexOf", "length", "size", "toDouble", "toFloat",
+        "toInt", "toUInt", "toULong", "toULongLong", "toUShort", "toUcs4" }};
 
     if (!clazy::contains(list, clazy::name(method)))
         return false;
@@ -161,7 +178,7 @@ bool StringRefCandidates::processCase1(CXXMemberCallExpr *memberCall)
     if (isFixitEnabled())
         fixits = fixit(firstMemberCall);
 
-    emitWarning(getLocEnd(firstMemberCall), "Use " + firstMethodName + "Ref() instead", fixits);
+    emitWarning(clazy::getLocEnd(firstMemberCall), "Use " + firstMethodName + "Ref() instead", fixits);
     return true;
 }
 
@@ -205,7 +222,7 @@ bool StringRefCandidates::processCase2(CallExpr *call)
         fixits = fixit(innerMemberCall);
     }
 
-    emitWarning(getLocStart(call), "Use " + innerMethod->getNameAsString() + "Ref() instead", fixits);
+    emitWarning(clazy::getLocStart(call), "Use " + innerMethod->getNameAsString() + "Ref() instead", fixits);
     return true;
 }
 
@@ -213,14 +230,14 @@ std::vector<FixItHint> StringRefCandidates::fixit(CXXMemberCallExpr *call)
 {
     MemberExpr *memberExpr = clazy::getFirstChildOfType<MemberExpr>(call);
     if (!memberExpr) {
-        queueManualFixitWarning(getLocStart(call), "Internal error 1");
+        queueManualFixitWarning(clazy::getLocStart(call), "Internal error 1");
         return {};
     }
 
-    auto insertionLoc = Lexer::getLocForEndOfToken(getLocEnd(memberExpr), 0, sm(), lo());
+    auto insertionLoc = Lexer::getLocForEndOfToken(clazy::getLocEnd(memberExpr), 0, sm(), lo());
     // llvm::errs() << insertionLoc.printToString(sm()) << "\n";
     if (!insertionLoc.isValid()) {
-        queueManualFixitWarning(getLocStart(call), "Internal error 2");
+        queueManualFixitWarning(clazy::getLocStart(call), "Internal error 2");
         return {};
     }
 
