@@ -1,39 +1,50 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2016-2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2016-2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "unused-non-trivial-variable.h"
-#include "Utils.h"
-
 #include "StringUtils.h"
 #include "HierarchyUtils.h"
 #include "ContextUtils.h"
 #include "QtUtils.h"
 #include "clazy_stl.h"
+#include "SourceCompatibilityHelpers.h"
+#include "TypeUtils.h"
 
-#include <clang/AST/AST.h>
-#include <clang/Lex/Lexer.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceLocation.h>
+#include <clang/Basic/SourceManager.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
 
+#include <stdlib.h>
 #include <vector>
 #include <string>
 
+class ClazyContext;
+
 using namespace clang;
 using namespace std;
 
@@ -110,8 +121,8 @@ bool UnusedNonTrivialVariable::isInterestingType(QualType t) const
                                                        "QStaticText", "QFontMetricsF", "QTextFrameFormat", "QTextImageFormat",
                                                        "QNetworkCookie", "QNetworkRequest", "QNetworkConfiguration",
                                                        "QHostAddress", "QSqlQuery", "QSqlRecord", "QSqlField",
-                                                       "QLine", "QLineF", "QRect", "QRectF"
-                                                     };
+                                                       "QLine", "QLineF", "QRect", "QRectF", "QDomNode"
+    };
 
     CXXRecordDecl *record = TypeUtils::typeAsRecord(t);
     if (!record)
@@ -148,7 +159,7 @@ void UnusedNonTrivialVariable::handleVarDecl(VarDecl *varDecl)
     if (!body)
         return;
 
-    SourceLocation locStart = getLocStart(varDecl);
+    SourceLocation locStart = clazy::getLocStart(varDecl);
     locStart = sm().getExpansionLoc(locStart);
     auto declRefs = clazy::getStatements<DeclRefExpr>(body, &sm(), locStart);
 
