@@ -1,31 +1,38 @@
 /*
   This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2017 Sergio Martins <sergio.martins@kdab.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "connect-3arg-lambda.h"
-#include "Utils.h"
 #include "HierarchyUtils.h"
 #include "QtUtils.h"
-#include "TypeUtils.h"
 
-#include <clang/AST/AST.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/Support/Casting.h>
+
+#include <vector>
+
+class ClazyContext;
 
 using namespace clang;
 using namespace std;
@@ -141,10 +148,10 @@ void Connect3ArgLambda::processQMenu(FunctionDecl *func, Stmt *stmt)
     // QMenu::addAction(const QString &text, Func1 slot, const QKeySequence &shortcut = 0)
     const uint numParams = func->getNumParams();
     if (numParams == 3) {
-           if (func->getParamDecl(0)->getNameAsString() == "text"  &&
-               func->getParamDecl(1)->getNameAsString() == "slot" &&
-               func->getParamDecl(2)->getNameAsString() == "shortcut") {
-               emitWarning(stmt, "Pass a context object as 2nd singleShot parameter");
-           }
-       }
+        if (func->getParamDecl(0)->getNameAsString() == "text"  &&
+            func->getParamDecl(1)->getNameAsString() == "slot" &&
+            func->getParamDecl(2)->getNameAsString() == "shortcut") {
+            emitWarning(stmt, "Pass a context object as 2nd singleShot parameter");
+        }
+    }
 }
