@@ -1,31 +1,38 @@
 /*
   This file is part of the clazy static checker.
 
-  Copyright (C) 2016-2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2016-2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "returning-data-from-temporary.h"
-#include "Utils.h"
 #include "HierarchyUtils.h"
-#include "QtUtils.h"
 #include "TypeUtils.h"
 
-#include <clang/AST/AST.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/Support/Casting.h>
+
+class ClazyContext;
 
 using namespace clang;
 using namespace std;
@@ -50,7 +57,7 @@ bool ReturningDataFromTemporary::handleReturn(ReturnStmt *ret)
         return false;
 
     auto memberCall = clazy::unpeal<CXXMemberCallExpr>(clazy::getFirstChild(ret), clazy::IgnoreExprWithCleanups |
-                                                                clazy::IgnoreImplicitCasts);
+                                                       clazy::IgnoreImplicitCasts);
     handleMemberCall(memberCall, false);
     return true;
 }
@@ -73,7 +80,7 @@ void ReturningDataFromTemporary::handleDeclStmt(DeclStmt *declStmt)
             continue;
 
         auto memberCall = clazy::unpeal<CXXMemberCallExpr>(clazy::getFirstChild(init), clazy::IgnoreExprWithCleanups |
-                                                                    clazy::IgnoreImplicitCasts);
+                                                           clazy::IgnoreImplicitCasts);
 
 
         handleMemberCall(memberCall, true);
