@@ -1,36 +1,48 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015,2018 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015,2018 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "function-args-by-ref.h"
 #include "Utils.h"
-#include "FixItUtils.h"
 #include "TypeUtils.h"
 #include "ClazyContext.h"
 #include "StringUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "clazy_stl.h"
+#include "FixItUtils.h"
 
-#include <clang/AST/AST.h>
-#include <clang/Lex/Lexer.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/Diagnostic.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/ADT/ArrayRef.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+
+#include <vector>
 
 using namespace clang;
 using namespace std;
@@ -54,7 +66,7 @@ static bool shouldIgnoreClass(CXXRecordDecl *record)
                                               "QtMetaTypePrivate::QAssociativeIterableImpl",
                                               "QVariantComparisonHelper",
                                               "QHashDummyValue", "QCharRef", "QString::Null"
-                                             };
+    };
     return clazy::contains(ignoreList, record->getQualifiedNameAsString());
 }
 
@@ -78,7 +90,7 @@ static bool shouldIgnoreFunction(clang::FunctionDecl *function)
                                                        "QWidget::addActions", // Fixed in Qt6
                                                        "QSslCertificate::verify", // Fixed in Qt6
                                                        "QSslConfiguration::setAllowedNextProtocols" // Fixed in Qt6
-                                                      };
+    };
 
     return clazy::contains(qualifiedIgnoreList, function->getQualifiedNameAsString());
 }
@@ -102,7 +114,7 @@ void FunctionArgsByRef::processFunction(FunctionDecl *func)
     if (m_context->isQtDeveloper() && shouldIgnoreFunction(func))
         return;
 
-    const bool warnForOverriddenMethods = isOptionSet("warn-for-overridden-methods");
+    const bool warnForOverriddenMethods = isOptionSet("warn-for-overridden-methods") || isFixitEnabled();
     if (!warnForOverriddenMethods && Utils::methodOverrides(dyn_cast<CXXMethodDecl>(func))) {
         // When overriding you can't change the signature. You should fix the base classes first
         return;
@@ -110,9 +122,9 @@ void FunctionArgsByRef::processFunction(FunctionDecl *func)
 
     Stmt *body = func->getBody();
 
-    int i = -1;
-    for (auto param : Utils::functionParameters(func)) {
-        i++;
+    auto funcParams = Utils::functionParameters(func);
+    for (unsigned int i = 0; i < funcParams.size(); ++i) {
+        ParmVarDecl* param = funcParams[i];
         QualType paramQt = TypeUtils::unrefQualType(param->getType());
         const Type *paramType = paramQt.getTypePtrOrNull();
         if (!paramType || paramType->isIncompleteType() || paramType->isDependentType())
@@ -140,7 +152,32 @@ void FunctionArgsByRef::processFunction(FunctionDecl *func)
                 error = "Missing reference on non-trivial type (" + paramStr + ')';
             }
 
-            emitWarning(getLocStart(param), error.c_str(), fixits);
+            addFixits(fixits, func, i);
+            emitWarning(clazy::getLocStart(param), error.c_str(), fixits);
+        }
+    }
+}
+
+void FunctionArgsByRef::addFixits(std::vector<FixItHint> &fixits, FunctionDecl *func, unsigned int parmIndex)
+{
+    if (isFixitEnabled()) {
+        for (auto funcRedecl : func->redecls()) {
+            auto funcParams = Utils::functionParameters(funcRedecl);
+            if (funcParams.size() <= parmIndex)
+                return;
+
+            ParmVarDecl *param = funcParams[parmIndex];
+            QualType paramQt = TypeUtils::unrefQualType(param->getType());
+
+            const bool isConst = paramQt.isConstQualified();
+
+            if (!isConst) {
+                SourceLocation start = clazy::getLocStart(param);
+                fixits.push_back(clazy::createInsertion(start, "const "));
+            }
+
+            SourceLocation end = param->getLocation();
+            fixits.push_back(clazy::createInsertion(end, "&"));
         }
     }
 }
@@ -153,7 +190,7 @@ void FunctionArgsByRef::VisitDecl(Decl *decl)
 void FunctionArgsByRef::VisitStmt(Stmt *stmt)
 {
     if (auto lambda = dyn_cast<LambdaExpr>(stmt)) {
-        if (!shouldIgnoreFile(getLocStart(stmt)))
+        if (!shouldIgnoreFile(clazy::getLocStart(stmt)))
             processFunction(lambda->getCallOperator());
     }
 }
