@@ -1,22 +1,22 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2016-2018 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2016-2018 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "function-args-by-value.h"
@@ -25,9 +25,31 @@
 #include "TypeUtils.h"
 #include "FixItUtils.h"
 #include "ClazyContext.h"
+#include "SourceCompatibilityHelpers.h"
+#include "clazy_stl.h"
 
-#include <clang/AST/AST.h>
-#include <clang/Lex/Lexer.h>
+#include <clang/AST/ASTContext.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/PrettyPrinter.h>
+#include <clang/AST/Redeclarable.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceLocation.h>
+#include <llvm/ADT/ArrayRef.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+#include <llvm/Support/raw_ostream.h>
+
+#include <iterator>
+#include <vector>
+
+namespace clang {
+class Decl;
+}  // namespace clang
 
 using namespace clang;
 using namespace std;
@@ -52,7 +74,7 @@ static bool shouldIgnoreClass(CXXRecordDecl *record)
                                               "QtMetaTypePrivate::QAssociativeIterableImpl",
                                               "QVariantComparisonHelper",
                                               "QHashDummyValue", "QCharRef", "QString::Null"
-                                             };
+    };
     return clazy::contains(ignoreList, record->getQualifiedNameAsString());
 }
 
@@ -76,7 +98,7 @@ static bool shouldIgnoreFunction(clang::FunctionDecl *function)
                                                        "QWidget::addActions", // Fixed in Qt6
                                                        "QSslCertificate::verify", // Fixed in Qt6
                                                        "QSslConfiguration::setAllowedNextProtocols" // Fixed in Qt6
-                                                      };
+    };
 
     return clazy::contains(qualifiedIgnoreList, function->getQualifiedNameAsString());
 }
@@ -171,7 +193,7 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
 
             const string paramStr = param->getType().getAsString();
             string error = "Pass small and trivially-copyable type by value (" + paramStr + ')';
-            emitWarning(getLocStart(param), error.c_str(), fixits);
+            emitWarning(clazy::getLocStart(param), error.c_str(), fixits);
         }
     }
 }
@@ -182,16 +204,16 @@ FixItHint FunctionArgsByValue::fixit(FunctionDecl *func, const ParmVarDecl *para
     QualType qt = TypeUtils::unrefQualType(param->getType());
     qt.removeLocalConst();
     const string typeName = qt.getAsString(PrintingPolicy(lo()));
-    string replacement = typeName + ' ' + string(param->getName());
-    SourceLocation startLoc = getLocStart(param);
-    SourceLocation endLoc = getLocEnd(param);
+    string replacement = typeName + ' ' + string(clazy::name(param));
+    SourceLocation startLoc = clazy::getLocStart(param);
+    SourceLocation endLoc = clazy::getLocEnd(param);
 
     const int numRedeclarations = std::distance(func->redecls_begin(), func->redecls_end());
     const bool definitionIsAlsoDeclaration = numRedeclarations == 1;
     const bool isDeclarationButNotDefinition = !func->doesThisDeclarationHaveABody();
 
     if (param->hasDefaultArg() && (isDeclarationButNotDefinition || definitionIsAlsoDeclaration)) {
-        endLoc = getLocStart(param->getDefaultArg()).getLocWithOffset(-1);
+        endLoc = clazy::getLocStart(param->getDefaultArg()).getLocWithOffset(-1);
         replacement += " =";
     }
 
