@@ -1,29 +1,28 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "old-style-connect.h"
-
 #include "Utils.h"
 #include "StringUtils.h"
 #include "FixItUtils.h"
@@ -31,15 +30,34 @@
 #include "QtUtils.h"
 #include "ClazyContext.h"
 #include "AccessSpecifierManager.h"
+#include "HierarchyUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "clazy_stl.h"
 
 #include <clang/AST/Decl.h>
 #include <clang/AST/DeclCXX.h>
-#include <clang/AST/AST.h>
-#include <clang/AST/DeclTemplate.h>
 #include <clang/Lex/Lexer.h>
+#include <clang/AST/DeclBase.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/ExprCXX.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/Type.h>
+#include <clang/Basic/Diagnostic.h>
+#include <clang/Basic/IdentifierTable.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceManager.h>
+#include <clang/Basic/TokenKinds.h>
+#include <clang/Lex/Token.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+#include <llvm/Support/raw_ostream.h>
 
 #include <regex>
 
+namespace clang {
+class MacroInfo;
+}  // namespace clang
+
 using namespace clang;
 using namespace std;
 
@@ -47,20 +65,20 @@ namespace clazy {
 // Copied from Clang's Expr.cpp and added "|| !DerivedType->isRecordType()" to avoid a crash
 const CXXRecordDecl *getBestDynamicClassType(Expr *expr)
 {
-  if (!expr)
-      return nullptr;
+    if (!expr)
+        return nullptr;
 
-  const Expr *E = expr->getBestDynamicClassTypeExpr();
-  QualType DerivedType = E->getType();
-  if (const PointerType *PTy = DerivedType->getAs<PointerType>())
-    DerivedType = PTy->getPointeeType();
+    const Expr *E = expr->getBestDynamicClassTypeExpr();
+    QualType DerivedType = E->getType();
+    if (const PointerType *PTy = DerivedType->getAs<PointerType>())
+        DerivedType = PTy->getPointeeType();
 
-  if (DerivedType->isDependentType() || !DerivedType->isRecordType())
-    return nullptr;
+    if (DerivedType->isDependentType() || !DerivedType->isRecordType())
+        return nullptr;
 
-  const RecordType *Ty = DerivedType->castAs<RecordType>();
-  Decl *D = Ty->getDecl();
-  return cast<CXXRecordDecl>(D);
+    const RecordType *Ty = DerivedType->castAs<RecordType>();
+    Decl *D = Ty->getDecl();
+    return cast<CXXRecordDecl>(D);
 }
 }
 
@@ -147,7 +165,7 @@ int OldStyleConnect::classifyConnect(FunctionDecl *connectFunc, CallExpr *connec
         // It's old style, but check if all macros are literals
         int numLiterals = 0;
         for (auto arg : connectCall->arguments()) {
-            auto argLocation = getLocStart(arg);
+            auto argLocation = clazy::getLocStart(arg);
             string dummy;
             if (isSignalOrSlot(argLocation, dummy))
                 ++numLiterals;
@@ -226,11 +244,11 @@ void OldStyleConnect::VisitStmt(Stmt *s)
         return;
 
     if (classification & ConnectFlag_Bogus) {
-        emitWarning(getLocStart(s), "Internal error");
+        emitWarning(clazy::getLocStart(s), "Internal error");
         return;
     }
 
-    emitWarning(getLocStart(s), "Old Style Connect", fixits(classification, call));
+    emitWarning(clazy::getLocStart(s), "Old Style Connect", fixits(classification, call));
 }
 
 void OldStyleConnect::addPrivateSlot(const PrivateSlot &slot)
@@ -261,7 +279,7 @@ string OldStyleConnect::signalOrSlotNameFromMacro(SourceLocation macroLoc)
     if (!macroLoc.isMacroID())
         return "error";
 
-    CharSourceRange expansionRange = getImmediateExpansionRange(macroLoc, sm());
+    CharSourceRange expansionRange = clazy::getImmediateExpansionRange(macroLoc, sm());
     SourceRange range = SourceRange(expansionRange.getBegin(), expansionRange.getEnd());
     auto charRange = Lexer::getAsCharRange(range, sm(), lo());
     const string text = Lexer::getSourceText(charRange, sm(), lo());
@@ -303,20 +321,20 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
     if (classification & ConnectFlag_2ArgsDisconnect) {
         // Not implemented yet
         string msg = "Fix it not implemented for disconnect with 2 args";
-        queueManualFixitWarning(getLocStart(call), msg);
+        queueManualFixitWarning(clazy::getLocStart(call), msg);
         return {};
     }
 
     if (classification & ConnectFlag_3ArgsDisconnect) {
         // Not implemented yet
         string msg = "Fix it not implemented for disconnect with 3 args";
-        queueManualFixitWarning(getLocStart(call), msg);
+        queueManualFixitWarning(clazy::getLocStart(call), msg);
         return {};
     }
 
     if (classification & ConnectFlag_QMessageBoxOpen) {
         string msg = "Fix it not implemented for QMessageBox::open()";
-        queueManualFixitWarning(getLocStart(call), msg);
+        queueManualFixitWarning(clazy::getLocStart(call), msg);
         return {};
     }
 
@@ -326,7 +344,7 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
     string macroName;
     CXXMethodDecl *senderMethod = nullptr;
     for (auto arg : call->arguments()) {
-        SourceLocation s = getLocStart(arg);
+        SourceLocation s = clazy::getLocStart(arg);
         static const CXXRecordDecl *lastRecordDecl = nullptr;
         if (isSignalOrSlot(s, macroName)) {
             macroNum++;
@@ -428,7 +446,7 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
             DeclContext *context = m_context->lastDecl->getDeclContext();
 
             bool isSpecialProtectedCase = false;
-            if (!clazy::canTakeAddressOf(methodDecl, context, /*by-ref*/isSpecialProtectedCase)) {
+            if (!clazy::canTakeAddressOf(methodDecl, context, /*by-ref*/ isSpecialProtectedCase)) {
                 string msg = "Can't fix " + clazy::accessString(methodDecl->getAccess()) + ' ' + macroName + ' ' + methodDecl->getQualifiedNameAsString();
                 queueManualFixitWarning(s, msg);
                 return {};
@@ -436,16 +454,16 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
 
             string qualifiedName;
             auto contextRecord = clazy::firstContextOfType<CXXRecordDecl>(m_context->lastDecl->getDeclContext());
-            const bool isInInclude = sm().getMainFileID() != sm().getFileID(getLocStart(call));
+            const bool isInInclude = sm().getMainFileID() != sm().getFileID(clazy::getLocStart(call));
 
             if (isSpecialProtectedCase && contextRecord) {
                 // We're inside a derived class trying to take address of a protected base member, must use &Derived::method instead of &Base::method.
-                qualifiedName = contextRecord->getNameAsString() + "::" + methodDecl->getNameAsString() ;
+                qualifiedName = contextRecord->getNameAsString() + "::" + methodDecl->getNameAsString();
             } else {
-                qualifiedName = clazy::getMostNeededQualifiedName(sm(), methodDecl, context, getLocStart(call), !isInInclude); // (In includes ignore using directives)
+                qualifiedName = clazy::getMostNeededQualifiedName(sm(), methodDecl, context, clazy::getLocStart(call), !isInInclude); // (In includes ignore using directives)
             }
 
-            CharSourceRange expansionRange = getImmediateExpansionRange(s, sm());
+            CharSourceRange expansionRange = clazy::getImmediateExpansionRange(s, sm());
             SourceRange range = SourceRange(expansionRange.getBegin(), expansionRange.getEnd());
 
             const string functionPointer = '&' + qualifiedName;
@@ -462,7 +480,7 @@ vector<FixItHint> OldStyleConnect::fixits(int classification, CallExpr *call)
             if (record) {
                 lastRecordDecl = record;
                 if (isQPointer(expr)) {
-                    auto endLoc = clazy::locForNextToken(&m_astContext, getLocStart(arg), tok::comma);
+                    auto endLoc = clazy::locForNextToken(&m_astContext, clazy::getLocStart(arg), tok::comma);
                     if (endLoc.isValid()) {
                         fixits.push_back(FixItHint::CreateInsertion(endLoc, ".data()"));
                     } else {
