@@ -1,25 +1,25 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
+    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    Author: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2015 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "qstring-allocations.h"
@@ -30,16 +30,31 @@
 #include "FixItUtils.h"
 #include "FunctionUtils.h"
 #include "QtUtils.h"
+#include "HierarchyUtils.h"
+#include "SourceCompatibilityHelpers.h"
 
 #include <clang/AST/DeclCXX.h>
 #include <clang/AST/ExprCXX.h>
 #include <clang/AST/Expr.h>
 #include <clang/Basic/Diagnostic.h>
-#include <clang/Rewrite/Frontend/FixItRewriter.h>
 #include <clang/Lex/Lexer.h>
-#include <clang/AST/ParentMap.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/Stmt.h>
+#include <clang/AST/StmtIterator.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceLocation.h>
+#include <clang/Frontend/CompilerInstance.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+#include <llvm/Support/raw_ostream.h>
 
-#include <iostream>
+#include <assert.h>
+
+namespace clang {
+class LangOptions;
+class ParentMap;
+class SourceManager;
+}  // namespace clang
 
 /// WARNING
 ///
@@ -207,23 +222,23 @@ void QStringAllocations::VisitCtor(Stmt *stm)
         auto qlatin1Ctor = qlatin1expr.qlatin1ctorexpr;
 
 
-        if (getLocStart(qlatin1Ctor).isMacroID()) {
-            auto macroName = Lexer::getImmediateMacroName(getLocStart(qlatin1Ctor), sm(), lo());
+        if (clazy::getLocStart(qlatin1Ctor).isMacroID()) {
+            auto macroName = Lexer::getImmediateMacroName(clazy::getLocStart(qlatin1Ctor), sm(), lo());
             if (macroName == "Q_GLOBAL_STATIC_WITH_ARGS") // bug #391807
                 return;
         }
 
         vector<FixItHint> fixits;
         if (qlatin1expr.enableFixit && isFixitEnabled(QLatin1StringAllocations)) {
-            if (!getLocStart(qlatin1Ctor).isMacroID()) {
+            if (!clazy::getLocStart(qlatin1Ctor).isMacroID()) {
                 if (!ternary) {
                     fixits = fixItReplaceWordWithWord(qlatin1Ctor, "QStringLiteral", "QLatin1String", QLatin1StringAllocations);
-                    bool shouldRemoveQString = getLocStart(qlatin1Ctor).getRawEncoding() != getLocStart(stm).getRawEncoding() && dyn_cast_or_null<CXXBindTemporaryExpr>(clazy::parent(m_context->parentMap, ctorExpr));
+                    bool shouldRemoveQString = clazy::getLocStart(qlatin1Ctor).getRawEncoding() != clazy::getLocStart(stm).getRawEncoding() && dyn_cast_or_null<CXXBindTemporaryExpr>(clazy::parent(m_context->parentMap, ctorExpr));
                     if (shouldRemoveQString) {
                         // This is the case of QString(QLatin1String("foo")), which we just fixed to be QString(QStringLiteral("foo)), so now remove QString
                         auto removalFixits = clazy::fixItRemoveToken(&m_astContext, ctorExpr, true);
                         if (removalFixits.empty())  {
-                            queueManualFixitWarning(getLocStart(ctorExpr), "Internal error: invalid start or end location", QLatin1StringAllocations);
+                            queueManualFixitWarning(clazy::getLocStart(ctorExpr), "Internal error: invalid start or end location", QLatin1StringAllocations);
                         } else {
                             clazy::append(removalFixits, fixits);
                         }
@@ -232,11 +247,11 @@ void QStringAllocations::VisitCtor(Stmt *stm)
                     fixits = fixItReplaceWordWithWordInTernary(ternary);
                 }
             } else {
-                queueManualFixitWarning(getLocStart(qlatin1Ctor), "Can't use QStringLiteral in macro", QLatin1StringAllocations);
+                queueManualFixitWarning(clazy::getLocStart(qlatin1Ctor), "Can't use QStringLiteral in macro", QLatin1StringAllocations);
             }
         }
 
-        emitWarning(getLocStart(stm), msg, fixits);
+        emitWarning(clazy::getLocStart(stm), msg, fixits);
     } else {
         vector<FixItHint> fixits;
         if (clazy::hasChildren(ctorExpr)) {
@@ -253,13 +268,13 @@ void QStringAllocations::VisitCtor(Stmt *stm)
                         const bool literalIsEmpty = lt->getLength() == 0;
                         if (literalIsEmpty && clazy::getFirstParentOfType<MemberExpr>(m_context->parentMap, ctorExpr) == nullptr)
                             fixits = fixItReplaceWordWithWord(ctorExpr, "QLatin1String", "QString", CharPtrAllocations);
-                        else if (!getLocStart(ctorExpr).isMacroID())
+                        else if (!clazy::getLocStart(ctorExpr).isMacroID())
                             fixits = fixItReplaceWordWithWord(ctorExpr, "QStringLiteral", "QString", CharPtrAllocations);
                         else
-                            queueManualFixitWarning(getLocStart(ctorExpr), "Can't use QStringLiteral in macro.", CharPtrAllocations);
+                            queueManualFixitWarning(clazy::getLocStart(ctorExpr), "Can't use QStringLiteral in macro.", CharPtrAllocations);
                     } else {
 
-                        auto parentMemberCallExpr = clazy::getFirstParentOfType<CXXMemberCallExpr>(m_context->parentMap, lt, /*maxDepth=*/6); // 6 seems like a nice max from the ASTs I've seen
+                        auto parentMemberCallExpr = clazy::getFirstParentOfType<CXXMemberCallExpr>(m_context->parentMap, lt, /*maxDepth=*/ 6); // 6 seems like a nice max from the ASTs I've seen
 
                         string replacement = "QStringLiteral";
                         if (parentMemberCallExpr) {
@@ -278,7 +293,7 @@ void QStringAllocations::VisitCtor(Stmt *stm)
             }
         }
 
-        emitWarning(getLocStart(stm), msg, fixits);
+        emitWarning(clazy::getLocStart(stm), msg, fixits);
     }
 }
 
@@ -287,7 +302,7 @@ vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt *begi
     StringLiteral *lt = stringLiteralForCall(begin);
     if (replacee == "QLatin1String") {
         if (lt && !Utils::isAscii(lt)) {
-            emitWarning(getLocStart(lt), "Don't use QLatin1String with non-latin1 literals");
+            emitWarning(clazy::getLocStart(lt), "Don't use QLatin1String with non-latin1 literals");
             return {};
         }
     }
@@ -298,7 +313,7 @@ vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt *begi
     vector<FixItHint> fixits;
     FixItHint fixit = clazy::fixItReplaceWordWithWord(&m_astContext, begin, replacement, replacee);
     if (fixit.isNull()) {
-        queueManualFixitWarning(getLocStart(begin), "", fixitType);
+        queueManualFixitWarning(clazy::getLocStart(begin), "", fixitType);
     } else {
         fixits.push_back(fixit);
     }
@@ -314,13 +329,13 @@ vector<FixItHint> QStringAllocations::fixItReplaceWordWithWordInTernary(clang::C
     vector<FixItHint> fixits;
     fixits.reserve(2);
     if (constructExprs.size() != 2) {
-        llvm::errs() << "Weird ternary operator with " << constructExprs.size() << " at " << getLocStart(ternary).printToString(sm()) << "\n";
+        llvm::errs() << "Weird ternary operator with " << constructExprs.size() << " at " << clazy::getLocStart(ternary).printToString(sm()) << "\n";
         assert(false);
         return fixits;
     }
 
     for (int i = 0; i < 2; ++i) {
-        SourceLocation rangeStart = getLocStart(constructExprs[i]);
+        SourceLocation rangeStart = clazy::getLocStart(constructExprs[i]);
         SourceLocation rangeEnd = Lexer::getLocForEndOfToken(rangeStart, -1, sm(), lo());
         fixits.push_back(FixItHint::CreateReplacement(SourceRange(rangeStart, rangeEnd), "QStringLiteral"));
     }
@@ -333,7 +348,7 @@ vector<FixItHint> QStringAllocations::fixItReplaceWordWithWordInTernary(clang::C
 // true for: QString s = QString::fromLatin1("foo")
 // false for: s += QString::fromLatin1("foo"), etc.
 static bool isQStringLiteralCandidate(Stmt *s, ParentMap *map, const LangOptions &lo,
-                                      const SourceManager &sm , int currentCall = 0)
+                                      const SourceManager &sm, int currentCall = 0)
 {
     if (!s)
         return false;
@@ -388,8 +403,8 @@ std::vector<FixItHint> QStringAllocations::fixItReplaceFromLatin1OrFromUtf8(Call
     std::string replacement = isQStringLiteralCandidate(callExpr, m_context->parentMap, lo(), sm()) ? "QStringLiteral"
                                                                                                     : "QLatin1String";
 
-    if (replacement == "QStringLiteral" && getLocStart(callExpr).isMacroID()) {
-        queueManualFixitWarning(getLocStart(callExpr), "Can't use QStringLiteral in macro!", FromLatin1_FromUtf8Allocations);
+    if (replacement == "QStringLiteral" && clazy::getLocStart(callExpr).isMacroID()) {
+        queueManualFixitWarning(clazy::getLocStart(callExpr), "Can't use QStringLiteral in macro!", FromLatin1_FromUtf8Allocations);
         return {};
     }
 
@@ -408,13 +423,13 @@ std::vector<FixItHint> QStringAllocations::fixItReplaceFromLatin1OrFromUtf8(Call
             }
         }
 
-        auto classNameLoc = Lexer::getLocForEndOfToken(getLocStart(callExpr), 0, sm(), lo());
+        auto classNameLoc = Lexer::getLocForEndOfToken(clazy::getLocStart(callExpr), 0, sm(), lo());
         auto scopeOperatorLoc = Lexer::getLocForEndOfToken(classNameLoc, 0, sm(), lo());
         auto methodNameLoc = Lexer::getLocForEndOfToken(scopeOperatorLoc, -1, sm(), lo());
-        SourceRange range(getLocStart(callExpr), methodNameLoc);
+        SourceRange range(clazy::getLocStart(callExpr), methodNameLoc);
         fixits.push_back(FixItHint::CreateReplacement(range, replacement));
     } else {
-        queueManualFixitWarning(getLocStart(callExpr), "Internal error: literal is null", FromLatin1_FromUtf8Allocations);
+        queueManualFixitWarning(clazy::getLocStart(callExpr), "Internal error: literal is null", FromLatin1_FromUtf8Allocations);
     }
 
     return fixits;
@@ -427,12 +442,12 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(clang::StringLiteral
     SourceRange range = clazy::rangeForLiteral(&m_astContext, lt);
     if (range.isInvalid()) {
         if (lt) {
-            queueManualFixitWarning(getLocStart(lt), "Internal error: Can't calculate source location", CharPtrAllocations);
+            queueManualFixitWarning(clazy::getLocStart(lt), "Internal error: Can't calculate source location", CharPtrAllocations);
         }
         return {};
     }
 
-    SourceLocation start = getLocStart(lt);
+    SourceLocation start = clazy::getLocStart(lt);
     if (start.isMacroID()) {
         queueManualFixitWarning(start, "Can't use QStringLiteral in macro", CharPtrAllocations);
     } else {
@@ -440,12 +455,12 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(clang::StringLiteral
             return {};
 
         string revisedReplacement = lt->getLength() == 0 ? "QLatin1String" : replacement; // QLatin1String("") is better than QStringLiteral("")
-        if (revisedReplacement == "QStringLiteral" && getLocStart(lt).isMacroID()) {
-            queueManualFixitWarning(getLocStart(lt), "Can't use QStringLiteral in macro...", CharPtrAllocations);
+        if (revisedReplacement == "QStringLiteral" && clazy::getLocStart(lt).isMacroID()) {
+            queueManualFixitWarning(clazy::getLocStart(lt), "Can't use QStringLiteral in macro...", CharPtrAllocations);
             return {};
         }
 
-        clazy::insertParentMethodCall(revisedReplacement, range, /**by-ref*/fixits);
+        clazy::insertParentMethodCall(revisedReplacement, range, /**by-ref*/ fixits);
     }
 
     return fixits;
@@ -494,7 +509,7 @@ void QStringAllocations::VisitOperatorCall(Stmt *stm)
 
     if (isFixitEnabled(CharPtrAllocations)) {
         if (literals.empty()) {
-            queueManualFixitWarning(getLocStart(stm), "Couldn't find literal", CharPtrAllocations);
+            queueManualFixitWarning(clazy::getLocStart(stm), "Couldn't find literal", CharPtrAllocations);
         } else {
             const string replacement = Utils::isAscii(literals[0]) ? "QLatin1String" : "QStringLiteral";
             fixits = fixItRawLiteral(literals[0], replacement);
@@ -502,7 +517,7 @@ void QStringAllocations::VisitOperatorCall(Stmt *stm)
     }
 
     string msg = string("QString(const char*) being called");
-    emitWarning(getLocStart(stm), msg, fixits);
+    emitWarning(clazy::getLocStart(stm), msg, fixits);
 }
 
 void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
@@ -537,7 +552,7 @@ void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
     if (!ternaries.empty()) {
         auto ternary = ternaries[0];
         if (Utils::ternaryOperatorIsOfStringLiteral(ternary)) {
-            emitWarning(getLocStart(stmt), string("QString::fromLatin1() being passed a literal"));
+            emitWarning(clazy::getLocStart(stmt), string("QString::fromLatin1() being passed a literal"));
         }
 
         return;
@@ -551,9 +566,9 @@ void QStringAllocations::VisitFromLatin1OrUtf8(Stmt *stmt)
     }
 
     if (clazy::name(functionDecl) == "fromLatin1") {
-        emitWarning(getLocStart(stmt), string("QString::fromLatin1() being passed a literal"), fixits);
+        emitWarning(clazy::getLocStart(stmt), string("QString::fromLatin1() being passed a literal"), fixits);
     } else {
-        emitWarning(getLocStart(stmt), string("QString::fromUtf8() being passed a literal"), fixits);
+        emitWarning(clazy::getLocStart(stmt), string("QString::fromUtf8() being passed a literal"), fixits);
     }
 }
 
@@ -579,5 +594,5 @@ void QStringAllocations::VisitAssignOperatorQLatin1String(Stmt *stmt)
                                     : fixItReplaceWordWithWordInTernary(ternary);
     }
 
-    emitWarning(getLocStart(stmt), string("QString::operator=(QLatin1String(\"literal\")"), fixits);
+    emitWarning(clazy::getLocStart(stmt), string("QString::operator=(QLatin1String(\"literal\")"), fixits);
 }
