@@ -1,31 +1,43 @@
 /*
-   This file is part of the clazy static checker.
+    This file is part of the clazy static checker.
 
-  Copyright (C) 2015 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "rule-of-three.h"
 #include "Utils.h"
 #include "MacroUtils.h"
-#include "StringUtils.h"
 #include "TypeUtils.h"
+#include "SourceCompatibilityHelpers.h"
+#include "clazy_stl.h"
 
-#include <clang/AST/AST.h>
+#include <clang/AST/DeclBase.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/Basic/LLVM.h>
+#include <clang/Basic/SourceLocation.h>
+#include <clang/Basic/SourceManager.h>
+#include <clang/Basic/Specifiers.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+
+#include <vector>
+
+class ClazyContext;
 
 using namespace clang;
 using namespace std;
@@ -46,10 +58,10 @@ void RuleOfThree::VisitDecl(clang::Decl *decl)
     if (record != record->getDefinition())
         return;
 
-    if (shouldIgnoreFile(getLocStart(decl)))
+    if (shouldIgnoreFile(clazy::getLocStart(decl)))
         return;
 
-    const SourceLocation recordStart = getLocStart(record);
+    const SourceLocation recordStart = clazy::getLocStart(record);
     if (recordStart.isMacroID()) {
         if (clazy::isInMacro(&m_astContext, recordStart, "Q_GLOBAL_STATIC_INTERNAL"))
             return;
@@ -63,14 +75,22 @@ void RuleOfThree::VisitDecl(clang::Decl *decl)
     const bool hasUserCopyCtor = copyCtor && copyCtor->isUserProvided();
     const bool hasUserCopyAssign = copyAssign && copyAssign->isUserProvided();
     const bool hasUserDtor = destructor && destructor->isUserProvided();
-    //const bool hasMoveCtor = record->hasNonTrivialMoveConstructor();
-    //const bool hasTrivialMoveAssignment = record->hasNonTrivialMoveAssignment();
-
 
     const bool copyCtorIsDeleted = copyCtor && copyCtor->isDeleted();
     const bool copyAssignIsDeleted = copyAssign && copyAssign->isDeleted();
 
-    if (hasUserDtor && (copyCtorIsDeleted || copyAssignIsDeleted)) {
+    bool hasImplicitDeletedCopy = false;
+    if (!copyCtor || !copyAssign) {
+        for (auto f : record->fields()) {
+            QualType qt = f->getType();
+            if (qt.isConstQualified() || qt->isRValueReferenceType()) {
+                hasImplicitDeletedCopy = true;
+                break;
+            }
+        }
+    }
+
+    if (hasUserDtor && (copyCtorIsDeleted || copyAssignIsDeleted || hasImplicitDeletedCopy)) {
         // One of the copy methods was explicitely deleted, it's safe.
         // The case we want to catch is when one is user-written and the other is
         // compiler-generated.
@@ -142,5 +162,5 @@ void RuleOfThree::VisitDecl(clang::Decl *decl)
             msg += ", ";
     }
 
-    emitWarning(getLocStart(decl), msg);
+    emitWarning(clazy::getLocStart(decl), msg);
 }
