@@ -1,33 +1,44 @@
 /*
   This file is part of the clazy static checker.
 
-  Copyright (C) 2017 Sergio Martins <smartins@kde.org>
+    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "thread-with-slots.h"
-#include "Utils.h"
 #include "HierarchyUtils.h"
 #include "QtUtils.h"
 #include "TypeUtils.h"
 #include "ClazyContext.h"
 #include "AccessSpecifierManager.h"
 
-#include <clang/AST/AST.h>
+#include <clang/AST/Decl.h>
+#include <clang/AST/DeclCXX.h>
+#include <clang/AST/Expr.h>
+#include <clang/AST/Stmt.h>
+#include <clang/Basic/LLVM.h>
+#include <llvm/ADT/StringRef.h>
+#include <llvm/Support/Casting.h>
+
+#include <vector>
+
+namespace clang {
+class Decl;
+}  // namespace clang
 
 using namespace clang;
 using namespace std;
@@ -39,7 +50,7 @@ static bool hasMutexes(Stmt *body)
     for (auto declref : declrefs) {
         ValueDecl *valueDecl = declref->getDecl();
         if (CXXRecordDecl *record = TypeUtils::typeAsRecord(valueDecl->getType())) {
-            if (record->getName() == "QMutex" || record->getName() == "QBasicMutex") {
+            if (clazy::name(record) == "QMutex" || clazy::name(record) == "QBasicMutex") {
                 return true;
             }
         }
@@ -70,7 +81,7 @@ void ThreadWithSlots::VisitStmt(clang::Stmt *stmt)
     if (!slot || !TypeUtils::derivesFrom(slot->getParent(), "QThread"))
         return;
 
-    if (slot->getParent()->getName() == "QThread") // The slots in QThread are thread safe, we're only worried about derived classes
+    if (clazy::name(slot->getParent()) == "QThread") // The slots in QThread are thread safe, we're only worried about derived classes
         return;
 
     QtAccessSpecifierType specifierType = m_context->accessSpecifierManager->qtAccessSpecifierType(slot);
@@ -90,7 +101,7 @@ void ThreadWithSlots::VisitDecl(Decl *decl)
         return;
 
     // The slots in QThread are thread safe, we're only worried about derived classes:
-    if (method->getParent()->getName() == "QThread")
+    if (clazy::name(method->getParent()) == "QThread")
         return;
 
     // We're only interested in slots:
@@ -108,7 +119,7 @@ void ThreadWithSlots::VisitDecl(Decl *decl)
     for (auto memberexpr : memberexprs) {
         ValueDecl *valueDecl = memberexpr->getMemberDecl();
         if (CXXRecordDecl *record = TypeUtils::typeAsRecord(valueDecl->getType())) {
-            if (record->getName() == "QMutex" || record->getName() == "QBasicMutex") {
+            if (clazy::name(record) == "QMutex" || clazy::name(record) == "QBasicMutex") {
                 return;
             }
         }
