@@ -12,5 +12,7 @@ void test()
     QObject::connect(o, &QObject::destroyed, o, []{}, Qt::UniqueConnection); // Warn
     o->connect(o, &QObject::destroyed, o, globalFunc, Qt::UniqueConnection); // Warn
     o->connect(o, &QObject::destroyed, o, &QObject::deleteLater, Qt::UniqueConnection); // OK
+    o->connect(o, QOverload<QObject*>::of(&QObject::destroyed), o, &QObject::deleteLater, Qt::UniqueConnection); // OK
+    o->connect(o, &QObject::destroyed, o, QOverload<>::of(&QObject::deleteLater), Qt::UniqueConnection); // OK
 }
 
