@@ -4,6 +4,8 @@ import sys, os, subprocess, string, re, json, threading, multiprocessing, argpar
 from threading import Thread
 from sys import platform as _platform
 
+_verbose = False
+
 def isWindows():
     return _platform == 'win32'
 
@@ -18,7 +20,7 @@ class QtInstallation:
 
 class Test:
     def __init__(self, check):
-        self.filename = ""
+        self.filenames = []
         self.minimum_qt_version = 500
         self.maximum_qt_version = 59999
         self.minimum_clang_version = 380
@@ -39,8 +41,13 @@ class Test:
         self.header_filter = ""
         self.ignore_dirs = ""
 
+    def filename(self):
+        if len(self.filenames) == 1:
+            return self.filenames[0]
+        return ""
+
     def isScript(self):
-        return self.filename.endswith(".sh")
+        return self.filename().endswith(".sh")
 
     def setQtMajorVersion(self, major_version):
         if major_version == 4:
@@ -74,6 +81,8 @@ class Check:
 
 def get_command_output(cmd, test_env = os.environ):
     try:
+        if _verbose:
+            print cmd
         output = subprocess.check_output(cmd, stderr=subprocess.STDOUT, shell=True, env=test_env)
     except subprocess.CalledProcessError, e:
         return e.output,False
@@ -115,7 +124,12 @@ def load_json(check_name):
         for t in decoded['tests']:
             test = Test(check)
             test.blacklist_platforms = check_blacklist_platforms
-            test.filename = t['filename']
+
+            if 'filename' in t:
+                test.filenames.append(t['filename'])
+
+            if 'filenames' in t:
+                test.filenames += t['filenames']
 
             if 'minimum_qt_version' in t:
                 test.minimum_qt_version = t['minimum_qt_version']
@@ -168,7 +182,7 @@ def load_json(check_name):
 
             check.tests.append(test)
             if test.isFixedFile:
-                fileToDelete = check_name + "/" + test.filename
+                fileToDelete = check_name + "/" + test.filename()
                 if os.path.exists(fileToDelete):
                     os.remove(fileToDelete)
 
@@ -198,11 +212,11 @@ def find_qt_installation(major_version, qmakes):
 
 def libraryName():
     if _platform == 'win32':
-        return 'ClangLazy.dll'
+        return 'ClazyPlugin.dll'
     elif _platform == 'darwin':
-        return 'ClangLazy.dylib'
+        return 'ClazyPlugin.dylib'
     else:
-        return 'ClangLazy.so'
+        return 'ClazyPlugin.so'
 
 def link_flags():
     flags = "-lQt5Core -lQt5Gui -lQt5Widgets"
@@ -214,7 +228,12 @@ def clazy_cpp_args():
     return "-Wno-unused-value -Qunused-arguments -std=c++14 "
 
 def more_clazy_args():
-    return " -Xclang -plugin-arg-clang-lazy -Xclang no-inplace-fixits " + clazy_cpp_args()
+    return " -Xclang -plugin-arg-clazy -Xclang no-inplace-fixits " + clazy_cpp_args()
+
+def clazy_standalone_binary():
+    if 'CLAZYSTANDALONE_CXX' in os.environ: # in case we want to use "clazy.AppImage --standalone" instead
+        return os.environ['CLAZYSTANDALONE_CXX']
+    return 'clazy-standalone'
 
 def clazy_standalone_command(test, qt):
     result = " -- " + clazy_cpp_args() + qt.compiler_flags() + " " + test.flags
@@ -248,23 +267,23 @@ def clazy_command(qt, test, filename):
         result = os.environ['CLAZY_CXX'] + more_clazy_args() + qt.compiler_flags()
     else:
         clang = os.getenv('CLANGXX', 'clang')
-        result = clang + " -Xclang -load -Xclang " + libraryName() + " -Xclang -add-plugin -Xclang clang-lazy " + more_clazy_args() + qt.compiler_flags()
+        result = clang + " -Xclang -load -Xclang " + libraryName() + " -Xclang -add-plugin -Xclang clazy " + more_clazy_args() + qt.compiler_flags()
 
     if test.qt4compat:
-        result = result + " -Xclang -plugin-arg-clang-lazy -Xclang qt4-compat "
+        result = result + " -Xclang -plugin-arg-clazy -Xclang qt4-compat "
 
     if test.only_qt:
-        result = result + " -Xclang -plugin-arg-clang-lazy -Xclang only-qt "
+        result = result + " -Xclang -plugin-arg-clazy -Xclang only-qt "
 
     if test.qt_developer:
-        result = result + " -Xclang -plugin-arg-clang-lazy -Xclang qt-developer "
+        result = result + " -Xclang -plugin-arg-clazy -Xclang qt-developer "
 
     if test.link and _platform.startswith('linux'): # Linking on one platform is enough. Won't waste time on macOS and Windows.
         result = result + " " + link_flags()
     else:
         result = result + " -c "
 
-    result = result + test.flags + " -Xclang -plugin-arg-clang-lazy -Xclang " + string.join(test.checks, ',') + " "
+    result = result + test.flags + " -Xclang -plugin-arg-clazy -Xclang " + string.join(test.checks, ',') + " "
     if not test.isFixedFile: # When compiling the already fixed file disable fixit, we don't want to fix twice
         result += _enable_fixits_argument + " "
     result += filename
@@ -272,26 +291,13 @@ def clazy_command(qt, test, filename):
     return result
 
 def dump_ast_command(test):
-    return "clang -std=c++14 -fsyntax-only -Xclang -ast-dump -fno-color-diagnostics -c " + qt_installation(test.qt_major_version).compiler_flags() + " " + test.flags + " " + test.filename
+    return "clang -std=c++14 -fsyntax-only -Xclang -ast-dump -fno-color-diagnostics -c " + qt_installation(test.qt_major_version).compiler_flags() + " " + test.flags + " " + test.filename()
 
 def compiler_name():
     if 'CLAZY_CXX' in os.environ:
         return os.environ['CLAZY_CXX'] # so we can set clazy.bat instead
     return os.getenv('CLANGXX', 'clang')
 
-#-------------------------------------------------------------------------------
-# Get clang version
-version,success = get_command_output(compiler_name() + ' --version')
-
-match = re.search('clang version (.*?)[ -]', version)
-try:
-    version = match.group(1)
-except:
-    print "Could not determine clang version, is it in PATH?"
-    sys.exit(-1)
-
-CLANG_VERSION = int(version.replace('.', ''))
-
 #-------------------------------------------------------------------------------
 # Setup argparse
 
@@ -311,7 +317,7 @@ if args.only_standalone and args.no_standalone:
 #-------------------------------------------------------------------------------
 # Global variables
 
-_enable_fixits_argument = "-Xclang -plugin-arg-clang-lazy -Xclang enable-all-fixits"
+_enable_fixits_argument = "-Xclang -plugin-arg-clazy -Xclang enable-all-fixits"
 _dump_ast = args.dump_ast
 _verbose = args.verbose
 _no_standalone = args.no_standalone
@@ -326,6 +332,26 @@ _excluded_checks = args.exclude.split(',') if args.exclude is not None else []
 #-------------------------------------------------------------------------------
 # utility functions #2
 
+version,success = get_command_output(compiler_name() + ' --version')
+
+match = re.search('clang version (.*?)[ -]', version)
+try:
+    version = match.group(1)
+except:
+    # Now try the Clazy.AppImage way
+    match = re.search('clang version: (.*)', version)
+
+    try:
+        version = match.group(1)
+    except:
+        print "Could not determine clang version, is it in PATH?"
+        sys.exit(-1)
+
+if _verbose:
+    print 'Found clang version: ' + str(version)
+
+CLANG_VERSION = int(version.replace('.', ''))
+
 def qt_installation(major_version):
     if major_version == 5:
         return _qt5_installation
@@ -401,6 +427,11 @@ def print_file(filename):
     print f.read()
     f.close()
 
+def file_contains(filename, text):
+    f = open(filename, 'r')
+    contents = f.read()
+    f.close()
+    return text in contents
 
 def run_unit_test(test, is_standalone):
     if test.check.clazy_standalone_only and not is_standalone:
@@ -415,16 +446,16 @@ def run_unit_test(test, is_standalone):
 
     if qt.int_version < test.minimum_qt_version or qt.int_version > test.maximum_qt_version or CLANG_VERSION < test.minimum_clang_version:
         if (_verbose):
-            print "Skipping " + test.check_name + " because required version is not available"
+            print "Skipping " + test.check.name + " because required version is not available"
         return True
 
     if _platform in test.blacklist_platforms:
         if (_verbose):
-            print "Skipping " + test.check_name + " because it is blacklisted for this platform"
+            print "Skipping " + test.check.name + " because it is blacklisted for this platform"
         return True
 
     checkname = test.check.name
-    filename = checkname + "/" + test.filename
+    filename = checkname + "/" + test.filename()
 
     output_file = filename + ".out"
     result_file = filename + ".result"
@@ -434,7 +465,7 @@ def run_unit_test(test, is_standalone):
         return True
 
     if is_standalone:
-        cmd_to_run = "clazy-standalone " + filename + " " + clazy_standalone_command(test, qt)
+        cmd_to_run = clazy_standalone_binary() + " " + filename + " " + clazy_standalone_command(test, qt)
     else:
         cmd_to_run = clazy_command(qt, test, filename)
 
@@ -448,6 +479,9 @@ def run_unit_test(test, is_standalone):
 
     cmd_success = run_command(cmd_to_run, output_file, test.env)
 
+    if file_contains(output_file, 'Invalid check: '):
+        return True
+
     if (not cmd_success and not must_fail) or (cmd_success and must_fail):
         print "[FAIL] " + checkname + " (Failed to build test. Check " + output_file + " for details)"
         print "-------------------"
@@ -463,7 +497,7 @@ def run_unit_test(test, is_standalone):
 
     printableName = checkname
     if len(test.check.tests) > 1:
-        printableName += "/" + test.filename
+        printableName += "/" + test.filename()
 
     if is_standalone:
         printableName += " (standalone)"
@@ -502,7 +536,7 @@ def run_unit_tests(tests):
 
 def dump_ast(check):
     for test in check.tests:
-        ast_filename = test.filename + ".ast"
+        ast_filename = test.filename() + ".ast"
         run_command(dump_ast_command(test) + " > " + ast_filename)
         print "Dumped AST to " + os.getcwd() + "/" + ast_filename
 #-------------------------------------------------------------------------------
@@ -525,6 +559,7 @@ if 'CLAZY_NO_WERROR' in os.environ:
     del os.environ['CLAZY_NO_WERROR']
 
 os.environ['CLAZY_CHECKS'] = ''
+os.environ['CLAZY_FIXIT_SUFFIX'] = '_fixed.cpp'
 
 all_check_names = get_check_names()
 all_checks = load_checks(all_check_names)
